package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.mapper.TaxiOrderMapper;
import com.ruoyi.system.domain.TaxiOrder;
import com.ruoyi.system.service.ITaxiOrderService;

/**
 * TaxiOrderService业务层处理
 * 
 * @author ruoyi
 * @date 2024-01-26
 */
@Service
public class TaxiOrderServiceImpl extends ServiceImpl<BaseMapper<TaxiOrder>,TaxiOrder> implements ITaxiOrderService
{
    @Autowired
    private TaxiOrderMapper taxiOrderMapper;

    /**
     * 查询TaxiOrder
     * 
     * @param id TaxiOrder主键
     * @return TaxiOrder
     */
    @Override
    public TaxiOrder selectTaxiOrderById(Long id)
    {
        return taxiOrderMapper.selectTaxiOrderById(id);
    }

    /**
     * 查询TaxiOrder列表
     * 
     * @param taxiOrder TaxiOrder
     * @return TaxiOrder
     */
    @Override
    public List<TaxiOrder> selectTaxiOrderList(TaxiOrder taxiOrder)
    {
        return taxiOrderMapper.selectTaxiOrderList(taxiOrder);
    }

    /**
     * 新增TaxiOrder
     * 
     * @param taxiOrder TaxiOrder
     * @return 结果
     */
    @Override
    public int insertTaxiOrder(TaxiOrder taxiOrder)
    {
        return taxiOrderMapper.insertTaxiOrder(taxiOrder);
    }

    /**
     * 修改TaxiOrder
     * 
     * @param taxiOrder TaxiOrder
     * @return 结果
     */
    @Override
    public int updateTaxiOrder(TaxiOrder taxiOrder)
    {
        return taxiOrderMapper.updateTaxiOrder(taxiOrder);
    }

    /**
     * 批量删除TaxiOrder
     * 
     * @param ids 需要删除的TaxiOrder主键
     * @return 结果
     */
    @Override
    public int deleteTaxiOrderByIds(Long[] ids)
    {
        return taxiOrderMapper.deleteTaxiOrderByIds(ids);
    }

    /**
     * 删除TaxiOrder信息
     * 
     * @param id TaxiOrder主键
     * @return 结果
     */
    @Override
    public int deleteTaxiOrderById(Long id)
    {
        return taxiOrderMapper.deleteTaxiOrderById(id);
    }
}
